#ifndef BOOST_SIMD_INCLUDE_CONSTANTS_FACT_12_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_CONSTANTS_FACT_12_HPP_INCLUDED

#include <boost/simd/constant/include/constants/fact_12.hpp>

#endif
